@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2018 ECMWF.
+ * Copyright 2005-2019 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
 
     outfile=argv[2];
 
-    f = fopen(argv[1],"r");
+    f = fopen(argv[1],"rb");
     if(!f) {
         perror(argv[1]);
         exit(1);
