@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2019 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -43,8 +43,8 @@ int main(int argc,char* argv[])
         return 1;
     }
 
-    in = fopen(infile,"r");
-    out = fopen(argv[1],"w");
+    in = fopen(infile,"rb");
+    out = fopen(argv[1],"wb");
 
     if (!in || !out) {
         perror("ERROR: unable to open files");
