@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2018 ECMWF.
+ * Copyright 2005-2019 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -16,7 +16,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <assert.h>
 #include "eccodes.h"
 
@@ -42,7 +41,7 @@ int main(int argc, char** argv)
 
     if (argc != 2) usage(argv[0]);
     filename=argv[1];
-    in = fopen(filename,"r");
+    in = fopen(filename,"rb");
     if(!in) {
         fprintf(stderr, "ERROR: unable to open file %s\n",filename);
         return 1;
