@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2017 ECMWF.
+ * Copyright 2005-2019 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -45,13 +45,13 @@ int main(int argc, char** argv)
     long bitsPerValue1=0, bitsPerValue2=0;
     int i=0;
 
-    in = fopen(infile,"r");
+    in = fopen(infile,"rb");
     if(!in) {
         printf("ERROR: unable to open input file %s\n",infile);
         return 1;
     }
 
-    out = fopen(outfile,"w");
+    out = fopen(outfile,"wb");
     if(!out) {
         printf("ERROR: unable to open output file %s\n",outfile);
         fclose(in);
