@@ -29,8 +29,8 @@ int main()
     }
 
     for (i=0; i<ni*nj; i++) {
-        double r = rand();
-        values[i] = 10*r;
+        double r = rand() * 1.0 / RAND_MAX;
+        values[i] = r;
     }
 
     h = codes_grib_handle_new_from_samples(0, "GRIB1");
