@@ -1,5 +1,5 @@
 !
-!Copyright 2005-2018 ECMWF.
+!Copyright 2005-2019 ECMWF.
 !
 ! This software is licensed under the terms of the Apache Licence Version 2.0
 !which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -23,7 +23,7 @@ integer            :: count=0
 integer(kind=4)    :: dataCategory,dataSubCategory,typicalDate
 integer(kind=4)    :: centre,subcentre
 integer(kind=4)    :: masterversion,localversion
-integer(kind=4)    :: numberofsubsets
+integer(kind=4)    :: numberOfSubsets
 
   call codes_open_file(ifile,'../../data/bufr/syno_multi.bufr','r')
 
@@ -57,8 +57,8 @@ integer(kind=4)    :: numberofsubsets
     call codes_get(ibufr,'localTablesVersionNumber',localversion)
     write(*,*) '  localTablesVersionNumber:',localversion
 
-    call codes_get(ibufr,'numberOfSubsets',numberofsubsets)
-    write(*,*) '  numberOfSubsets:',numberofsubsets
+    call codes_get(ibufr,'numberOfSubsets',numberOfSubsets)
+    write(*,*) '  numberOfSubsets:',numberOfSubsets
 
     ! Release the bufr message
     call codes_release(ibufr)
