@@ -1,5 +1,5 @@
 !
-!Copyright 2005-2017 ECMWF.
+!Copyright 2005-2019 ECMWF.
 !
 ! This software is licensed under the terms of the Apache Licence Version 2.0
 !which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -58,7 +58,7 @@ real(kind=8), dimension(:), allocatable :: year
     call codes_get(ibufr,'latitude',latVal);
 
     ! Get longitude (for all the subsets)
-    call codes_get(ibufr,'latitude',lonVal);
+    call codes_get(ibufr,'longitude',lonVal);
 
     allocate(year(numObs))
     call codes_get(ibufr,'year',year);
