@@ -1,4 +1,4 @@
-# Copyright 2005-2018 ECMWF.
+# Copyright 2005-2019 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -21,11 +21,10 @@ import sys
 
 from eccodes import *
 
-INPUT = '../../data/bufr/syno_1.bufr'
 VERBOSE = 1  # verbose error reporting
 
 
-def example():
+def example(INPUT):
     # open bufr file
     f = open(INPUT, 'rb')
 
@@ -67,7 +66,7 @@ def example():
 
 def main():
     try:
-        example()
+        example(sys.argv[1])
     except CodesInternalError as err:
         if VERBOSE:
             traceback.print_exc(file=sys.stderr)
