@@ -5,6 +5,6 @@
 # To get verbose output
 #$PYTHON -m unittest -v high_level_api
 
-$PYTHON $examples_src/high_level_api.py
+$PYTHON $examples_src/high_level_api.py -v
 
 rm -f test.index
