@@ -137,156 +137,162 @@ static void init_class(grib_accessor_class* c)
 
 static void init(grib_accessor* a, const long len , grib_arguments* arg )
 {
-  a->length = len;
-  Assert(a->length>=0);
+    a->length = len;
+    Assert(a->length>=0);
 }
 
-static int value_count(grib_accessor* a,long* count){
-  *count=1;
-  return 0;
+static int value_count(grib_accessor* a,long* count)
+{
+    *count=1;
+    return 0;
 }
 
-static size_t string_length(grib_accessor* a){
-  return a->length;
+static size_t string_length(grib_accessor* a)
+{
+    return a->length;
 }
 
 static void dump(grib_accessor* a, grib_dumper* dumper)
 {
-  grib_dump_string(dumper,a,NULL);
+    grib_dump_string(dumper,a,NULL);
 }
 
-static int  get_native_type(grib_accessor* a){
-  return GRIB_TYPE_STRING;
+static int  get_native_type(grib_accessor* a)
+{
+    return GRIB_TYPE_STRING;
 }
 
 static int unpack_string(grib_accessor* a, char* val, size_t *len)
 {
-  int i = 0;
-  grib_handle* hand = grib_handle_of_accessor(a);
+    int i = 0;
+    grib_handle* hand = grib_handle_of_accessor(a);
 
-  if(len[0] < (a->length+1))
-  {
-    grib_context_log(a->context, GRIB_LOG_ERROR, "unpack_string: Wrong size (%d) for %s it contains %d values ", len[0], a->name , a->length+1 );
-    len[0] = 0;
-    return GRIB_ARRAY_TOO_SMALL;
-  }
+    if(len[0] < (a->length+1))
+    {
+        grib_context_log(a->context, GRIB_LOG_ERROR, "unpack_string: Wrong size (%d) for %s it contains %d values ", len[0], a->name , a->length+1 );
+        len[0] = 0;
+        return GRIB_ARRAY_TOO_SMALL;
+    }
 
-  for ( i = 0; i < a->length; i++)
-    val[i] = hand->buffer->data[a->offset+i];
-  val[i] = 0;
-  len[0] = i;
-  return GRIB_SUCCESS;
+    for ( i = 0; i < a->length; i++)
+        val[i] = hand->buffer->data[a->offset+i];
+    val[i] = 0;
+    len[0] = i;
+    return GRIB_SUCCESS;
 }
 
 static int pack_string(grib_accessor* a, const char* val, size_t *len)
 {
-  int i = 0;
-  grib_handle* hand = grib_handle_of_accessor(a);
-  if(len[0] > (a->length)+1)
-  {
-    grib_context_log(a->context, GRIB_LOG_ERROR, "pack_string: Wrong size (%d) for %s it contains %d values ", len[0], a->name , a->length+1 );
-    len[0] = 0;
-    return GRIB_BUFFER_TOO_SMALL;
-  }
+    int i = 0;
+    grib_handle* hand = grib_handle_of_accessor(a);
+    if(len[0] > (a->length)+1)
+    {
+        grib_context_log(a->context, GRIB_LOG_ERROR, "pack_string: Wrong size (%d) for %s it contains %d values ", len[0], a->name , a->length+1 );
+        len[0] = 0;
+        return GRIB_BUFFER_TOO_SMALL;
+    }
 
-  for ( i = 0; i < a->length; i++)
-  {
-    if( i < len[0] )
-      hand->buffer->data[a->offset+i] = val[i];
-    else
-      hand->buffer->data[a->offset+i] = 0;
-  }
+    for ( i = 0; i < a->length; i++)
+    {
+        if( i < len[0] )
+            hand->buffer->data[a->offset+i] = val[i];
+        else
+            hand->buffer->data[a->offset+i] = 0;
+    }
 
-  return GRIB_SUCCESS;
+    return GRIB_SUCCESS;
 }
 
-static int pack_long(grib_accessor* a, const long*  v, size_t *len){
-  grib_context_log(a->context,GRIB_LOG_ERROR, " Should not pack %s as long", a->name);
-  return GRIB_NOT_IMPLEMENTED;
+static int pack_long(grib_accessor* a, const long*  v, size_t *len)
+{
+    grib_context_log(a->context,GRIB_LOG_ERROR, " Should not pack %s as long", a->name);
+    return GRIB_NOT_IMPLEMENTED;
 }
 
-static int pack_double(grib_accessor* a, const double*v, size_t *len){
-  grib_context_log(a->context,GRIB_LOG_ERROR, " Should not pack %s  as double", a->name);
-  return GRIB_NOT_IMPLEMENTED;
+static int pack_double(grib_accessor* a, const double*v, size_t *len)
+{
+    grib_context_log(a->context,GRIB_LOG_ERROR, " Should not pack %s  as double", a->name);
+    return GRIB_NOT_IMPLEMENTED;
 }
 
+static int  unpack_long   (grib_accessor* a, long*  v, size_t *len)
+{
+    char val[1024]={0,};
+    size_t l = sizeof(val);
+    size_t i =0;
+    char  *last = NULL;
+    int err=grib_unpack_string (a , val, &l);
 
-static int  unpack_long   (grib_accessor* a, long*  v, size_t *len){
+    if (err) return err;
 
-  char val[1024]={0,};
-  size_t l = sizeof(val);
-  size_t i =0;
-  char  *last = NULL;
-  int err=grib_unpack_string (a , val, &l);
+    i=0;
+    while ( val[i]==' ' && val[i]!=0  && i<l-1) i++;
 
-  if (err) return err;
+    if (val[i]==0) {
+        *v=0;
+        return 0;
+    }
+    if (val[i+1]==' ' && i<l-2)  val[i+1]=0;
 
-  i=0;
-  while ( val[i]==' ' && val[i]!=0  && i<l-1) i++;
+    *v = strtol(val,&last,10);
 
-  if (val[i]==0) {
-     *v=0;
-     return 0;
-  }
-  if (val[i+1]==' ' && i<l-2)  val[i+1]=0;
-
-  *v = strtol(val,&last,10);
-
-  grib_context_log(a->context,GRIB_LOG_DEBUG, " Casting string %s to long", a->name);
-  return GRIB_SUCCESS;
-
-}
-
-static int unpack_double (grib_accessor* a, double*v, size_t *len){
-  char val[1024];
-  size_t l = sizeof(val);
-  char  *last = NULL;
-  grib_unpack_string (a , val, &l);
-
-  *v = strtod(val,&last);
-
-  if(*last == 0)
-  {
     grib_context_log(a->context,GRIB_LOG_DEBUG, " Casting string %s to long", a->name);
     return GRIB_SUCCESS;
-  }
-
-  return GRIB_NOT_IMPLEMENTED;
 }
 
+static int unpack_double (grib_accessor* a, double*v, size_t *len)
+{
+    char val[1024];
+    size_t l = sizeof(val);
+    char  *last = NULL;
 
-static int compare(grib_accessor* a,grib_accessor* b) {
-  int retval=0;
-  char *aval=0;
-  char *bval=0;
-  int err=0;
+    grib_unpack_string (a , val, &l);
 
-  size_t alen = 0;
-  size_t blen = 0;
-  long count=0;
+    *v = strtod(val,&last);
 
-  err=grib_value_count(a,&count);
-  if (err) return err;
-  alen=count;
+    if(*last == 0)
+    {
+        grib_context_log(a->context,GRIB_LOG_DEBUG, " Casting string %s to long", a->name);
+        return GRIB_SUCCESS;
+    }
 
-  err=grib_value_count(b,&count);
-  if (err) return err;
-  blen=count;
+    grib_context_log(a->context,GRIB_LOG_WARNING,"Cannot unpack %s as double. Hint: Try unpacking as string",a->name);
 
-  if (alen != blen) return GRIB_COUNT_MISMATCH;
-
-  aval=(char*)grib_context_malloc(a->context,alen*sizeof(char));
-  bval=(char*)grib_context_malloc(b->context,blen*sizeof(char));
-
-  grib_unpack_string(a,aval,&alen);
-  grib_unpack_string(b,bval,&blen);
-
-  retval = GRIB_SUCCESS;
-  if (strcmp(aval,bval)) retval = GRIB_STRING_VALUE_MISMATCH;
-
-  grib_context_free(a->context,aval);
-  grib_context_free(b->context,bval);
-
-  return retval;
+    return GRIB_NOT_IMPLEMENTED;
 }
 
+static int compare(grib_accessor* a,grib_accessor* b)
+{
+    int retval=0;
+    char *aval=0;
+    char *bval=0;
+    int err=0;
+
+    size_t alen = 0;
+    size_t blen = 0;
+    long count=0;
+
+    err=grib_value_count(a,&count);
+    if (err) return err;
+    alen=count;
+
+    err=grib_value_count(b,&count);
+    if (err) return err;
+    blen=count;
+
+    if (alen != blen) return GRIB_COUNT_MISMATCH;
+
+    aval=(char*)grib_context_malloc(a->context,alen*sizeof(char));
+    bval=(char*)grib_context_malloc(b->context,blen*sizeof(char));
+
+    grib_unpack_string(a,aval,&alen);
+    grib_unpack_string(b,bval,&blen);
+
+    retval = GRIB_SUCCESS;
+    if (strcmp(aval,bval)) retval = GRIB_STRING_VALUE_MISMATCH;
+
+    grib_context_free(a->context,aval);
+    grib_context_free(b->context,bval);
+
+    return retval;
+}
